# pgZhSearch简介

> django-postgresql环境下的中文全文检索. QuickStart参考Git主页!


## 参考文献

- https://juejin.cn/post/6844903480893636616
- https://cainiaojiaocheng.com/Django/docs/3.2.x/ref/contrib/postgres/search

